Documentation
¶
Index ¶
- type ToolHandler
- func (h *ToolHandler) HandleToolGolangGetConstAndVarDoc(ctx context.Context, req *godoc.ToolGolangGetConstAndVarDocRequest) (*mcp.CallToolResult, error)
- func (h *ToolHandler) HandleToolGolangGetFuncDoc(ctx context.Context, req *godoc.ToolGolangGetFuncDocRequest) (*mcp.CallToolResult, error)
- func (h *ToolHandler) HandleToolGolangGetMethodDoc(ctx context.Context, req *godoc.ToolGolangGetMethodDocRequest) (*mcp.CallToolResult, error)
- func (h *ToolHandler) HandleToolGolangGetStructDoc(ctx context.Context, req *godoc.ToolGolangGetStructDocRequest) (*mcp.CallToolResult, error)
- func (h *ToolHandler) HandleToolGolangInspectPackage(ctx context.Context, req *godoc.ToolGolangInspectPackageRequest) (*mcp.CallToolResult, error)
- func (h *ToolHandler) HandleToolGolangListPackages(ctx context.Context, req *godoc.ToolGolangListPackagesRequest) (*mcp.CallToolResult, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ToolHandler ¶
type ToolHandler struct {
// contains filtered or unexported fields
}
ToolHandler is a handler structure that processes MCP tool requests.
func NewToolHandler ¶
func NewToolHandler(p *parser.Parser) *ToolHandler
NewToolHandler creates a new ToolHandler instance.
func (*ToolHandler) HandleToolGolangGetConstAndVarDoc ¶
func (h *ToolHandler) HandleToolGolangGetConstAndVarDoc(ctx context.Context, req *godoc.ToolGolangGetConstAndVarDocRequest) (*mcp.CallToolResult, error)
HandleToolGolangGetConstAndVarDoc returns information about constants and variables in the specified package.
func (*ToolHandler) HandleToolGolangGetFuncDoc ¶
func (h *ToolHandler) HandleToolGolangGetFuncDoc(ctx context.Context, req *godoc.ToolGolangGetFuncDocRequest) (*mcp.CallToolResult, error)
HandleToolGolangGetFuncDoc returns information about the specified function.
func (*ToolHandler) HandleToolGolangGetMethodDoc ¶
func (h *ToolHandler) HandleToolGolangGetMethodDoc(ctx context.Context, req *godoc.ToolGolangGetMethodDocRequest) (*mcp.CallToolResult, error)
HandleToolGolangGetMethodDoc returns information about the specified method of a struct.
func (*ToolHandler) HandleToolGolangGetStructDoc ¶
func (h *ToolHandler) HandleToolGolangGetStructDoc(ctx context.Context, req *godoc.ToolGolangGetStructDocRequest) (*mcp.CallToolResult, error)
HandleToolGolangGetStructDoc returns information about the specified struct.
func (*ToolHandler) HandleToolGolangInspectPackage ¶
func (h *ToolHandler) HandleToolGolangInspectPackage(ctx context.Context, req *godoc.ToolGolangInspectPackageRequest) (*mcp.CallToolResult, error)
HandleToolGolangInspectPackage lists exported structs, methods, and functions in the specified package.
func (*ToolHandler) HandleToolGolangListPackages ¶
func (h *ToolHandler) HandleToolGolangListPackages(ctx context.Context, req *godoc.ToolGolangListPackagesRequest) (*mcp.CallToolResult, error)
HandleToolGolangListPackages returns a list of all loaded packages.